@@ -2,8 +2,8 @@ import datetime
 
 from reader import Content
 from reader import Enclosure
-from reader.core.types import EntryData
-from reader.core.types import FeedData
+from reader._types import EntryData
+from reader._types import FeedData
 
 
 feed = FeedData(url='{}empty.atom'.format(url_base))
