@@ -2,8 +2,8 @@ import datetime
 
 from reader import Content
 from reader import Enclosure
-from reader.core.types import EntryData
-from reader.core.types import FeedData
+from reader._types import EntryData
+from reader._types import FeedData
 
 
 feed = FeedData(
@@ -16,6 +16,13 @@ entries = [
         id='urn:uuid:1225c695-cfb8-4ebb-aaaa-80da344efa6a',
         updated=None,
         link='{}entries/entry.html'.format(rel_base),
+        summary='one <a href="{}target">two</a> three'.format(rel_base),
+        content=(
+            Content(
+                value='<script>evil</script> content', type='text/plain', language=None
+            ),
+            Content(value='content', type='text/html', language=None),
+        ),
         enclosures=(
             # the text/html type comes from feedparser
             Enclosure(
