@@ -3,6 +3,8 @@ from datetime import datetime
 import pytest
 from fakeparser import Parser
 from fakeparser import ParserThatRemembers
+from utils import naive_datetime
+from utils import utc_datetime
 
 from reader import Entry
 from reader import Feed
@@ -11,12 +13,14 @@ from reader import make_reader
 from reader._storage import Storage
 
 
-@pytest.mark.parametrize('entry_updated', [datetime(2010, 1, 1), None])
+@pytest.mark.parametrize('entry_updated', [utc_datetime(2010, 1, 1), None])
 def test_update_stale(reader, call_update_method, entry_updated):
     """When a feed is marked as stale feeds/entries should be updated
     regardless of their .updated or caching headers.
 
     """
+    from utils import utc_datetime as datetime
+
     parser = ParserThatRemembers()
     parser.http_etag = 'etag'
     parser.http_last_modified = 'last-modified'
@@ -30,7 +34,7 @@ def test_update_stale(reader, call_update_method, entry_updated):
 
     reader.add_feed(feed.url)
 
-    reader._now = lambda: datetime(2010, 1, 1)
+    reader._now = lambda: naive_datetime(2010, 1, 1)
     call_update_method(reader, feed.url)
 
     assert set((f.url, f.title, f.last_updated) for f in reader.get_feeds()) == {
@@ -51,7 +55,7 @@ def test_update_stale(reader, call_update_method, entry_updated):
 
     if entry_updated:
         # nothing changes after update
-        reader._now = lambda: datetime(2010, 1, 2)
+        reader._now = lambda: naive_datetime(2010, 1, 2)
         call_update_method(reader, feed.url)
         assert set((f.url, f.title, f.last_updated) for f in reader.get_feeds()) == {
             (feed.url, feed.title, datetime(2010, 1, 1))
@@ -63,7 +67,7 @@ def test_update_stale(reader, call_update_method, entry_updated):
     # but it does if we mark the feed as stale
     parser.calls[:] = []
     reader._storage.mark_as_stale(feed.url)
-    reader._now = lambda: datetime(2010, 1, 3)
+    reader._now = lambda: naive_datetime(2010, 1, 3)
     call_update_method(reader, feed.url)
     assert parser.calls == [(feed.url, None, None)]
     assert set((f.url, f.title, f.last_updated) for f in reader.get_feeds()) == {
@@ -76,6 +80,7 @@ def test_update_stale(reader, call_update_method, entry_updated):
 
 def test_update_parse(reader, call_update_method):
     """Updated feeds should pass caching headers back to ._parser()."""
+    from utils import utc_datetime as datetime
 
     parser = ParserThatRemembers()
     parser.http_etag = 'etag'
@@ -97,6 +102,8 @@ def test_update_parse(reader, call_update_method):
 
 def test_post_feed_update_plugins(reader):
     parser = Parser()
+    parser.tzinfo = False
+
     reader._parser = parser
 
     plugin_calls = []
